==> eisp-mdm-3.6.6.release-classes.jar: com/biz/eisp/mdm/terminal/sql/TmTermCustPostDao_findTermListByCustomerId.sql <==
SELECT tc.id,
       term.id           terminalId,
       term.terminal_code,
       term.terminal_name,
       term.ADDRESS,
       term.LINKMAN_PHONE,
       term.LINKMAN,
       cust.CUSTOMER_CODE,
       cust.CUSTOMER_NAME,
       tp.POSITION_CODE,
       tp.POSITION_NAME,
       term.PROVINCE,
       term.CITY,
       term.AREA,
       term.terminal_type
FROM TM_R_TERM_CUST_POS_BG tc
         JOIN TM_TERMINAL term ON term.ID = tc.TERMINAL_ID
         left join TM_CUSTOMER cust on cust.id = tc.CUSTOMER_ID
         left join TM_POSITION tp on tp.id = tc.POSITION_ID
WHERE 1 = 1

       <#if tmTermCustPostVo.customerId ?exists&&tmTermCustPostVo.customerId ?length gt 0>
       AND tc.CUSTOMER_ID = '${tmTermCustPostVo.customerId}'
    </#if>

<#if tmTermCustPostVo.customerCode ?exists&&tmTermCustPostVo.customerCode ?length gt 0>
	AND cust.CUSTOMER_CODE LIKE '%${tmTermCustPostVo.customerCode}%'
</#if>

<#if tmTermCustPostVo.customerName ?exists&&tmTermCustPostVo.customerName ?length gt 0>
	AND cust.CUSTOMER_NAME LIKE '%${tmTermCustPostVo.customerName}%'
</#if>

<#if tmTermCustPostVo.positionId ?exists&&tmTermCustPostVo.positionId ?length gt 0>
    AND tc.POSITION_ID= '${tmTermCustPostVo.positionId}'
</#if>

<#if tmTermCustPostVo.terminalId ?exists&&tmTermCustPostVo.terminalId ?length gt 0>
      AND tc.TERMINAL_ID = '${tmTermCustPostVo.terminalId}'
</#if>

<#if tmTermCustPostVo.terminalCode ?exists&&tmTermCustPostVo.terminalCode ?length gt 0>
	AND term.TERMINAL_CODE LIKE '%${tmTermCustPostVo.terminalCode}%'
</#if>

<#if tmTermCustPostVo.terminalName ?exists&&tmTermCustPostVo.terminalName ?length gt 0>
	AND term.TERMINAL_NAME LIKE '%${tmTermCustPostVo.terminalName}%'
</#if>

<#if tmTermCustPostVo.terminalType ?exists&&tmTermCustPostVo.terminalType ?length gt 0>
	AND term.TERMINAL_TYPE = '${tmTermCustPostVo.terminalType}'
</#if>

<#if tmTermCustPostVo.province ?exists&&tmTermCustPostVo.province ?length gt 0>
	AND term.province LIKE '%${tmTermCustPostVo.province}%'
</#if>

<#if tmTermCustPostVo.city ?exists&&tmTermCustPostVo.city ?length gt 0>
	AND term.city LIKE '%${tmTermCustPostVo.city}%'
</#if>

<#if tmTermCustPostVo.area ?exists&&tmTermCustPostVo.area ?length gt 0>
	AND term.area LIKE '%${tmTermCustPostVo.area}%'
</#if>

order by tc.CREATE_DATE desc

==> eisp-mdm-3.8.4.release-classes.jar: com/biz/eisp/mdm/terminal/sql/TmTermCustPostDao_findTermListByCustomerId.sql <==
SELECT tc.id,
       term.id           terminalId,
       term.terminal_code,
       term.terminal_name,
       term.ADDRESS,
       term.LINKMAN_PHONE,
       term.LINKMAN,
       cust.CUSTOMER_CODE,
       cust.CUSTOMER_NAME,
       tr.org_name,
       tco.cust_org_name,
       tp.POSITION_CODE,
       tp.POSITION_NAME,
       term.province,
       term.city,
       term.area,
       term.terminal_type
FROM TM_R_TERM_CUST_POS_BG tc
         JOIN TM_TERMINAL term ON term.ID = tc.TERMINAL_ID
         left join TM_CUSTOMER cust on cust.id = tc.CUSTOMER_ID
         left join TM_POSITION tp on tp.id = tc.POSITION_ID
         LEFT JOIN TM_CUSTOMER_ORG  tco ON tco.ID=term.customer_org_id
         LEFT JOIN TM_ORG tr ON tr.ID=term.ORG_ID
WHERE 1 = 1

       <#if tmTermCustPostVo.customerId ?exists&&tmTermCustPostVo.customerId ?length gt 0>
       AND tc.CUSTOMER_ID = '${tmTermCustPostVo.customerId}'
    </#if>

<#if tmTermCustPostVo.customerCode ?exists&&tmTermCustPostVo.customerCode ?length gt 0>
	AND cust.CUSTOMER_CODE LIKE '%${tmTermCustPostVo.customerCode}%'
</#if>

<#if tmTermCustPostVo.customerName ?exists&&tmTermCustPostVo.customerName ?length gt 0>
	AND cust.CUSTOMER_NAME LIKE '%${tmTermCustPostVo.customerName}%'
</#if>

<#if tmTermCustPostVo.positionId ?exists&&tmTermCustPostVo.positionId ?length gt 0>
    AND tc.POSITION_ID= '${tmTermCustPostVo.positionId}'
</#if>

<#if tmTermCustPostVo.terminalId ?exists&&tmTermCustPostVo.terminalId ?length gt 0>
      AND tc.TERMINAL_ID = '${tmTermCustPostVo.terminalId}'
</#if>

<#if tmTermCustPostVo.terminalCode ?exists&&tmTermCustPostVo.terminalCode ?length gt 0>
	AND term.TERMINAL_CODE LIKE '%${tmTermCustPostVo.terminalCode}%'
</#if>

<#if tmTermCustPostVo.terminalName ?exists&&tmTermCustPostVo.terminalName ?length gt 0>
	AND term.TERMINAL_NAME LIKE '%${tmTermCustPostVo.terminalName}%'
</#if>

<#if tmTermCustPostVo.terminalType ?exists&&tmTermCustPostVo.terminalType ?length gt 0>
	AND term.TERMINAL_TYPE = '${tmTermCustPostVo.terminalType}'
</#if>

<#if tmTermCustPostVo.province ?exists&&tmTermCustPostVo.province ?length gt 0>
	AND term.province LIKE '%${tmTermCustPostVo.province}%'
</#if>

<#if tmTermCustPostVo.city ?exists&&tmTermCustPostVo.city ?length gt 0>
	AND term.city LIKE '%${tmTermCustPostVo.city}%'
</#if>

<#if tmTermCustPostVo.area ?exists&&tmTermCustPostVo.area ?length gt 0>
	AND term.area LIKE '%${tmTermCustPostVo.area}%'
</#if>

<#if tmTermCustPostVo.custOrgName ?exists&&tmTermCustPostVo.custOrgName ?length gt 0>
	AND tco.CUST_ORG_NAME LIKE '%${tmTermCustPostVo.custOrgName}%'
</#if>
<#if tmTermCustPostVo.orgName ?exists&&tmTermCustPostVo.orgName ?length gt 0>
	AND tr.org_name LIKE '%${tmTermCustPostVo.orgName}%'
</#if>
order by tc.CREATE_DATE desc
